@@ -10,11 +10,8 @@
 
 package stock_browser;
 
-use constant TRUE => 1;
-use constant FALSE => 0;
-
+use Glib qw(TRUE FALSE);
 use Gtk2;
-use Data::Dumper;
 
 my $window = undef;
 
