@@ -1,7 +1,7 @@
 /*
  * 
- * Copyright (C) 2003 by the gtk2-perl team (see the file AUTHORS for the full
- * list)
+ * Copyright (C) 2003-2004 by the gtk2-perl team (see the file AUTHORS for the
+ * full list)
  * 
  * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Library General Public License as published by
@@ -18,7 +18,7 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
  * 
  *
- * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/gtk2perl.h,v 1.30 2004/05/11 17:41:12 kaffeetisch Exp $
+ * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/gtk2perl.h,v 1.37 2005/07/11 22:39:12 kaffeetisch Exp $
  */
 
 #ifndef _GTK2PERL_H_
@@ -27,18 +27,32 @@
 #include <gperl.h>
 #include <gtk/gtk.h>
 
-/* custom GType for GdkRegion */
-#define GDK_TYPE_REGION (gtk2perl_gdk_region_get_type ())
-GType gtk2perl_gdk_region_get_type (void) G_GNUC_CONST;
-
-/* custom GType for PangoLayoutIter */
-#define PANGO_TYPE_LAYOUT_ITER (gtk2perl_pango_layout_iter_get_type ())
-GType gtk2perl_pango_layout_iter_get_type (void) G_GNUC_CONST;
-
-#include "gtk2perl-autogen.h"
 #include "gtk2perl-versions.h"
 
-#ifdef GDK_WINDOWING_WIN32 /* no plug/socket on win32 despite patches exist for years. */
+/* custom GType for GdkRegion */
+#ifndef GDK_TYPE_REGION
+# define GDK_TYPE_REGION (gtk2perl_gdk_region_get_type ())
+  GType gtk2perl_gdk_region_get_type (void) G_GNUC_CONST;
+#endif
+
+/* custom GType for PangoLayoutIter */
+#ifndef PANGO_TYPE_LAYOUT_ITER
+# define PANGO_TYPE_LAYOUT_ITER (gtk2perl_pango_layout_iter_get_type ())
+  GType gtk2perl_pango_layout_iter_get_type (void) G_GNUC_CONST;
+#endif
+
+/* custom GType for PangoScriptIter */
+#if PANGO_CHECK_VERSION (1, 4, 0)
+# ifndef PANGO_TYPE_SCRIPT_ITER
+#  define PANGO_TYPE_SCRIPT_ITER (gtk2perl_pango_script_iter_get_type ())
+   GType gtk2perl_pango_script_iter_get_type (void) G_GNUC_CONST;
+# endif
+#endif
+
+#include "gtk2perl-autogen.h"
+
+/* no plug/socket on non-X11 despite patches exist for years. */
+#ifndef GDK_WINDOWING_X11
 # undef GTK_TYPE_PLUG
 # undef GTK_TYPE_SOCKET
 #endif
@@ -173,4 +187,10 @@ SV * newSVGdkGeometry (GdkGeometry *geometry);
 GdkGeometry * SvGdkGeometry (SV *object);
 GdkGeometry * SvGdkGeometryReal (SV *object, GdkWindowHints *hints);
 
+/* special handling for GdkPixbufFormat, which was introduced in gtk+ 2.2.0 */
+#if GTK_CHECK_VERSION (2, 2, 0)
+SV * newSVGdkPixbufFormat (GdkPixbufFormat * format);
+GdkPixbufFormat * SvGdkPixbufFormat (SV * sv);
+#endif
+
 #endif /* _GTK2PERL_H_ */
